#!/bin/bash
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada (and in future epics)
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

#set -x
#verbose=0
#if [ x$1 = x"" ]; then 
#    export verbose=0
#else
#    export verbose=1
#fi

PASS=0
FAIL=1
export PATH=.:$PATH
#source scadat_unittest.sh
echo "Call: `which scadat`"

assertGrep.sh "scadat -l" "sys/tg_test/1"
if (( $? == $FAIL )) ; then
    echo "$0: require running device sys/tg_test/1 at TANGO_HOST:$TANGO_HOST"
    exit 0
fi

if [ -z "$TANGO_HOST" ]; then
    export TANGO_HOST="scadat.org:10000"
    echo "TANGO_HOST not set: export TANGO_HOST=scadat.org:10000"
fi  

assertTrue.sh "scadat $TANGO_HOST"
assertFalse.sh "scadat scadat.org:1234" stderr
assertEqual.sh "scadat scadat.org:1234" "set TANGO_HOST e.g. export TANGO_HOST=scadat.org:10000" stderr
assertEqual.sh "scadat" "scadat -h: For usage"
assertGrep.sh "scadat -i" "scadat_version"
assertGrep.sh "scadat -l" "sys/tg_test/1"
assertGrep.sh "scadat Unknown" "set TANGO_HOST e.g. export TANGO_HOST=scadat.org:10000" stderr
assertGrep.sh "scadat -r aa/bb/cc" "Cannot Open device aa/bb/cc on" stderr
assertEqual.sh "scadat -c sys/tg_test/1/Init" "None"
assertEqual.sh "scadat -r sys/tg_test/1 | grep Status" "sys/tg_test/1/Status <attr_ro>"
assertGrep.sh "scadat -c sys/tg_test/1/DevFloat 12.34" "12.34"
assertGrep.sh "scadat -c sys/tg_test/1" "Usage: scadat -c sys/tg_test/1 <cmd_name> value"
assertGrep.sh "scadat -c sys/tg_test/1/Status" "The device is"
assertEqual.sh "scadat -c sys/tg_test/1/DevDouble 12.34" "12.34"
assertEqual.sh "scadat -c sys/tg_test/1/DevLong 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevLong64 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevULong64 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevULong 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevBoolean 0" "False"
assertEqual.sh "scadat -c sys/tg_test/1/DevBoolean 1" "True"
assertEqual.sh "scadat -c sys/tg_test/1/DevShort 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevUShort 1234" "1234"
assertEqual.sh "scadat -c sys/tg_test/1/DevString 'my string'" "my string"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarLongArray '1 2 3 4'" "[1 2 3 4]"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarLong64Array '1 2 3 4'" "[1 2 3 4]"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarULong64Array '1 2 3 4'" "[1 2 3 4]"
assertGrep.sh "scadat -c sys/tg_test/1/DevVarFloatArray '1.123456 2.2 3.3 4.4'" "1.123456"
assertGrep.sh "scadat -c sys/tg_test/1/DevVarDoubleArray '1.123456 2.2 3.3 4.4'" "1.123456"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarUShortArray '1 2 3 4'" "[1 2 3 4]"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarShortArray '1 2 3 4'" "[1 2 3 4]"
assertEqual.sh "scadat -c sys/tg_test/1/DevVarStringArray 'string1 string2 string3 string4'" "['string1', 'string2', 'string3', 'string4']"
assertEqual.sh "scadat -c sys/tg_test/1/DevVoid None" "None"
# attribute_read_all
assertEqual.sh "scadat -r sys/tg_test/1 | grep long_scalar_rww" "sys/tg_test/1/long_scalar_rww <attr_w>"
assertEqual.sh "scadat -r sys/tg_test/1 | grep ulong_image_ro" "sys/tg_test/1/ulong_image_ro <attr_ro>"
# attribute_read_single
assertGrep.sh "scadat -r sys/tg_test/1 | grep 'short_scalar_rww'" "sys/tg_test/1/short_scalar_rww"
# Read 1 command
assertEqual.sh "scadat -r sys/tg_test/1 | grep ushort_scalar" "sys/tg_test/1/ushort_scalar <attr_w>"
assertEqual.sh "scadat -r sys/tg_test/1 | grep long_scalar_w" "sys/tg_test/1/long_scalar_w <attr_w>"
# Write/Read Attributes
assertGrep.sh "scadat -w sys/tg_test/1" "Usage: scadat -w sys/tg_test/1 <attr_name_w> value"
assertEqual.sh "scadat -w sys/tg_test/1/long_scalar_w" "Usage: scadat -w sys/tg_test/1  long_scalar_w <DevLong>"
assertEqual.sh "scadat -w sys/tg_test/1/long_scalar_w 4321" "sys/tg_test/1/long_scalar_w->4321"
assertEqual.sh "scadat -r sys/tg_test/1/long_scalar_w" "4321"
#assertTrue.sh "scadat -r sys/tg_test/1/long_scalar_w | grep '[0-9]\+'"
assertEqual.sh "scadat -w sys/tg_test/1/long_scalar_w 1234" "sys/tg_test/1/long_scalar_w->1234"
assertEqual.sh "scadat -r sys/tg_test/1/long_scalar_w" "1234"
assertEqual.sh "scadat -w sys/tg_test/1/string_scalar 'my string 123'" "sys/tg_test/1/string_scalar->my string 123"
assertEqual.sh "scadat -r sys/tg_test/1/string_scalar" "my string 123"
assertGrep.sh "scadat -r sys/tg_test/1/string_scalar -v" "sys/tg_test/1/string_scalar my string 123"
assertGrep.sh "scadat -r bad/device/name" "Cannot Open device bad/device/name" stderr
assertGrep.sh "scadat -r bad/device/name sys/tg_test/1" "sys/tg_test/1" stderr

#assertEqual.sh "scadat scadat.org:10000 -v" "tango_open:TANGO_HOST=scadat.org:10000"
#result=$?
##echo "result is $result"
#if [ "$result" != "0" ]; then
#    echo "Check network: nc -vz -w1 scadat.org 10000 - Network access- failed"
#else
#    echo "Check network: nc -vz -w1 scadat.org 10000 - Network access- ok"
#fi

#assertEqual.sh "scadat -r sys/tg_test/1 | grep short_scalar_w" "sys/tg_test/1/short_scalar_w 4321"
#assertEqual.sh "scadat -w sys/tg_test/1 short_scalar_w 4321" "short_scalar_w->4321"
#### Not supported - yet
#assertGrep.sh "$scadat -w sys/tg_test/1 DevVarDoubleStringArray '1 2 3 4'" "1 2 3 4"
#assertGrep.sh "$scadat -w sys/tg_test/1 DevVarCharArray '1 2 3 4'" "1 2 3 4"
#assertGrep.sh "$scadat -w sys/tg_test/1 DevVarLongStringArray 1234" "1234"
#echo "epics tests:"
#export SCADAT_HOST="EPICS"
#assertGrep.sh "$scadat -r 'CO_TEST:CLOCK1:SEC1' -v" "CO_TEST:CLOCK1:SEC1"
