#!/usr/bin/python
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

import os,sys,re
import argparse
import scadat_tango
import scadat_utils

parser = argparse.ArgumentParser(description=\
        "Linux command line interface to tango control system\n"
        ,formatter_class=argparse.RawTextHelpFormatter)
#        ,formatter_class=argparse.ArgumentDefaultsHelpFormatter)
parser.add_argument("host",nargs="?",
        help="scadat <host>:<port>  (e.g. localhost:10000 or scadat.org:10000)")
parser.add_argument("-v", "--verbose",action="count",default=0,
        help="increase output verbosity using -v,-vv,-vvv")
group = parser.add_mutually_exclusive_group()
group.add_argument("-i","--info",action="store_true",
        help="Information on tango installation")
group.add_argument("-l","--ldev",action="store_true",
        help="List tango devices\n"
        "scadat -l\n"
        "scadat scadat.org:10000 -l -vv\n")
group.add_argument("-r","--read",nargs='+',
        help="Read attributes from a devices: e.g.\n"
        "scadat scadat.org:10000 -r sys/tg_test/1\n"
        "scadat -r sys/tg_test/1\n"
        "scadat -r sys/.*/.*\n"
        "scadat -r sys/tg_test/1 string_scalar -v")
group.add_argument("-w","--write",nargs='+',
        help="Write to attributes of a device: e.g.\n"
             "scadat -w sys/tg_test/1\n"
             "scadat -w sys/tg_test/1 string_scalar 'hello world'")
group.add_argument("-c","--cmd",nargs='+',
        help="Send command to a device: e.g.\n"
             "scadat -c sys/tg_test/1 -v\n"
             "scadat -c sys/tg_test/1 DevLong 1234\n"
             "scadat -c sys/tg_test/1 State")

args=parser.parse_args()

if len(sys.argv)==1:
    print ("scadat -h: For usage")
    sys.exit(1)

scadat_utils.verbose=args.verbose
myscadat=scadat_tango.scadat_tango(verbose=args.verbose,host=args.host)

if args.info:
    myscadat.info()
elif args.ldev:
    myscadat.ldev()
elif args.read:
    if len(args.read)==1:
        myscadat.read(args.read[0])
    else:
        myscadat.read(args.read[0],args.read[1:])
elif args.write:
    if len(args.write)==1:
        myscadat.write(args.write[0])
    elif len(args.write)==2:
        myscadat.write(args.write[0],args.write[1])
    elif len(args.write)==3:
        myscadat.write(args.write[0],args.write[1],args.write[2])
    else:
        print ("format scadat sys/tg_test/1 <arg> <value>")
elif args.cmd:
    if len(args.cmd)==1:
        myscadat.cmd(args.cmd[0])
    elif len(args.cmd)==2:
        myscadat.cmd(args.cmd[0],args.cmd[1])
    elif len(args.cmd)==3:
        myscadat.cmd(args.cmd[0],args.cmd[1],args.cmd[2])
    else:
        print ("%s sys/tg_test/1 <arg> <value>")
sys.exit(0)
